@@ -1,7 +1,7 @@
-# -*- coding: utf-8 -*-
+from __future__ import annotations
 
 
-def add_uppercase_char(char_list):
+def add_uppercase_char(char_list: list[tuple[str, str]]) -> list[tuple[str, str]]:
     """ Given a replacement char list, this adds uppercase chars to the list """
 
     for item in char_list:
@@ -10,6 +10,7 @@ def add_uppercase_char(char_list):
         if upper_dict not in char_list and char != upper_dict[0]:
             char_list.insert(0, upper_dict)
         return char_list
+    return char_list
 
 
 # Language specific pre translations
